@@ -46,15 +46,29 @@ typedef struct _GdkPixbufClass GdkPixbufClass;
 #define GDK_IS_PIXBUF_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GDK_TYPE_PIXBUF))
 #define GDK_PIXBUF_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), GDK_TYPE_PIXBUF, GdkPixbufClass))
 
-/* Helper macros to convert between density units */
-#define DPI_TO_DPM(value) ((int) round ((value) * 1000 / 25.4))
-#define DPI_TO_DPCM(value) ((int) round ((value) / 2.54))
-#define DPM_TO_DPI(value) ((int) round ((value) * 25.4 / 1000))
-#define DPCM_TO_DPI(value) ((int) round ((value) * 2.54))
-
 /* Default fill color */
 #define DEFAULT_FILL_COLOR 0x979899ff
 
+typedef enum {
+        STORAGE_PIXELS,
+        STORAGE_BYTES
+} Storage;
+
+typedef struct {
+        /* The pixel array */
+        guchar *pixels;
+
+        /* Destroy notification function; it is supposed to free the pixel array */
+        GdkPixbufDestroyNotify destroy_fn;
+
+        /* User data for the destroy notification function */
+        gpointer destroy_fn_data;
+} Pixels;
+
+typedef struct {
+        GBytes *bytes;
+} Bytes;
+
 /* Private part of the GdkPixbuf structure */
 struct _GdkPixbuf {
         GObject parent_instance;
@@ -74,17 +88,12 @@ struct _GdkPixbuf {
 	/* Offset between rows */
 	int rowstride;
 
-	/* The pixel array */
-	guchar *pixels;
+        Storage storage;
 
-	/* Destroy notification function; it is supposed to free the pixel array */
-	GdkPixbufDestroyNotify destroy_fn;
-
-	/* User data for the destroy notification function */
-	gpointer destroy_fn_data;
-
-        /* Replaces "pixels" member (and destroy notify) */
-        GBytes *bytes;
+        struct {
+                Pixels pixels;
+                Bytes bytes;
+        } s;
 
 	/* Do we have an alpha channel? */
 	guint has_alpha : 1;
